import collections

import requests
import six


class NLU:
    NLU_URL = "https://vins-markup.voicetech.yandex.net/markup/0.x/"

    def __init__(self, key):
        """Class for parse input text.

        Args:
            key: API-key for Yandex speech kit.
        """
        self.key = key

        self.__test_the_key()

    def __test_the_key(self):
        """Test the validity of the key.
        """
        params = {
            "text": "test",
            "key": self.key,
        }

        status = requests.get(self.NLU_URL, params=params).status_code
        if status == 400:
            raise Exception("Key banned or inactive")

    def parse(self, text, layers=None):
        """Parsing passed text to json.

        Args:
            text: Text to parse.
            layers (optional): Special fields. Only one string
                or iterable object (e.g "Data", ("Data", "Fio")).
                Only these fields will be returned.


        Returns:
            The parsed text into a json object.
        """
        params = {
            "text": text,
            "key": self.key,
        }

        if layers is not None:
            # if it's string
            if isinstance(layers, six.string_types):
                params["layers"] = layers

            # if it's another iterable object
            elif isinstance(layers, collections.Iterable):
                params["layers"] = ",".join(layers)

        req = requests.get(self.NLU_URL, params=params)
        return req.json()



import os

import requests


class TTS:
    TTS_URL = "https://tts.voicetech.yandex.net/generate"
    MAX_CHARS = 2000

    def __init__(self, speaker, audio_format, key, lang="ru-RU", **kwargs):
        """Class for generate of speech.

        Args:
            speaker: Speaker.
            audio_format: Audio file format.
            key: API-key for Yandex speech kit.
            lang (optional): Language. Defaults to "ru-RU".
            emotion (optional): The color of the voice. Defaults to "normal".
            speed (optional): Speech tempo. Defaults to 1.0.
        """
        self.__params = {
            "speaker": speaker,
            "format": audio_format,
            "key": key,
            "lang": lang,
        }
        self.__params.update(kwargs)
        self._data = None

    def generate(self, text):
        """Try to get the generated file.

        Args:
            text: The text that you want to generate.
        """
        if not text:
            raise Exception("No text to speak")

        if len(text) >= self.MAX_CHARS:
            raise Exception("Number of characters must be less than 2000")

        params = self.__params.copy()
        params["text"] = text
        self._data = requests.get(self.TTS_URL, params=params,
                                  stream=False).iter_content()

    def save(self, path="speech"):
        """Save data in file.

        Args:
            path (optional): A path to save file. Defaults to "speech".
                File extension is optional. Absolute path is allowed.

        Returns:
            The path to the saved file.
        """
        if self._data is None:
            raise Exception("There's nothing to save")

        extension = "." + self.__params["format"]
        if os.path.splitext(path)[1] != extension:
            path += extension

        with open(path, "wb") as f:
            for d in self._data:
                f.write(d)

        return path



import os

from setuptools import setup


NAME = "yandex_speech"
VERSION_PATH = os.path.join(os.path.dirname(__file__), NAME, "VERSION.txt")
with open(VERSION_PATH) as f:
    version = f.read().strip()

setup(
    name=NAME,
    description="A library for Yandex speech kit",
    long_description=open("README.rst").read(),
    url="https://github.com/art1415926535/Yandex_speech",
    version=version,
    packages=[NAME],
    package_data={NAME: ["VERSION.txt"]},
    install_requires=["requests", "six"],
    license="MIT",
    author="Artem Fedotov",
    author_email="art1415926535@ya.ru",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: Russian",
        "Natural Language :: English",
        "Natural Language :: Turkish",
        "Natural Language :: Ukranian",
        "Topic :: Multimedia :: Sound/Audio :: Speech"
    ],
    keywords="yandex speech kit text-to-speech tts",
)
